package cn.com.ty.lift.system.homepage.service;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.constants.CommonConstants;
import cn.com.ty.lift.system.homepage.dao.dto.request.TodoRequest;
import cn.com.ty.lift.system.homepage.dao.dto.response.AnnualInspectionResponse;
import cn.com.ty.lift.system.homepage.dao.dto.response.CapitalRepairResponse;
import cn.com.ty.lift.system.homepage.dao.dto.response.EmergencyResponse;
import cn.com.ty.lift.system.homepage.dao.dto.response.MaintenanceTodoResponse;
import cn.com.ty.lift.system.homepage.dao.mapper.TodoDataMapper;
import cn.com.ty.lift.system.settings.dao.entity.MtCompanyAttestation;
import cn.com.ty.lift.system.settings.service.IMtCompanyAttestationService;
import cn.com.ty.lift.system.user.dao.entity.UserApplication;
import cn.com.ty.lift.system.user.service.IUserApplicationService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @author huangyuan
 * @date 2020/2/14
 * @description
 */
@Service
public class TodoService {

    @Resource
    private TodoDataMapper todoDataMapper;

    @Resource
    private IMtCompanyAttestationService mtCompanyAttestationService;

    @Resource
    private IUserApplicationService userApplicationService;

    /**
     * @param todoRequest 公司id
     * @return
     * @description 待办数量
     * @date 2020/2/14 10:55 上午
     */
    public RestResponse todoNum(TodoRequest todoRequest) {
        Map<Integer, Long> todoTypeToNum = CommonConstants.TODO_TYPE_TO_NUM;
        //1.设置行政待办事项数量
        //团队成员申请待办
        long administrativeTodoCount = userApplicationService.count(new QueryWrapper<UserApplication>()
                .eq("status", ApiConstants.ApplicationConstants.APPLY_WAIT)
        );
        //公司申请待办,平台公司才能有公司申请待办
        if(todoRequest.getMtCompanyId() == ApiConstants.PLATFORM_COMPANY_ID){
            long platCompanyTodoCount = mtCompanyAttestationService.count(new QueryWrapper<MtCompanyAttestation>()
                    .eq("is_certificated", ApiConstants.CompanyConstants.MAINTENANCE_WAIT_CERTIFICATE)
            );
            administrativeTodoCount = administrativeTodoCount + platCompanyTodoCount;
        }
        todoTypeToNum.put(CommonConstants.TodoConstants.ADMINISTRATIVE_TODO, administrativeTodoCount);
        //2.设置急修待办数量
        long emergencyTodoCount = todoDataMapper.getEmergencyTodoCount(todoRequest);
        todoTypeToNum.put(CommonConstants.TodoConstants.EMERGENCY_TODO, emergencyTodoCount);
        //3.设置维保待办数量
        long maintenanceTodoCount = todoDataMapper.getMaintenanceTodoCount(todoRequest);
        todoTypeToNum.put(CommonConstants.TodoConstants.MAINTENANCE_TODO, maintenanceTodoCount);
        //4.设置大修待办数量
        long capitalRepairTodoCount = todoDataMapper.getCapitalTodoCount(todoRequest);
        todoTypeToNum.put(CommonConstants.TodoConstants.CAPITAL_REPAIR_TODO, capitalRepairTodoCount);
        //5.设置年检待办数量
        long annualTodoCount = todoDataMapper.getAnnualTodoCount(todoRequest);
        todoTypeToNum.put(CommonConstants.TodoConstants.ANNUAL_INSPECTION_TODO, annualTodoCount);
        return RestResponse.success(todoTypeToNum, ApiConstants.RESULT_SUCCESS, "获取待办数据成功");
    }

    /**
     * @param
     * @return
     * @description 获取急修待待办数据
     * @date 2020/2/14 12:20 下午
     */
    public RestResponse getEmergencyTodo(TodoRequest todoRequest) {
        List<EmergencyResponse> emergencyTodoResponseList = todoDataMapper.getEmergencyTodoData(todoRequest);
        return RestResponse.success(emergencyTodoResponseList, ApiConstants.RESULT_SUCCESS, "获取待办数据成功");
    }

    /**
     * @param
     * @return
     * @description 获取维保待办
     * @date 2020/2/14 12:21 下午
     */
    public RestResponse getMaintenanceTodo(TodoRequest todoRequest) {
        List<MaintenanceTodoResponse> maintenanceTodoResponseList = todoDataMapper.getMaintenanceTodoData(todoRequest);
        return RestResponse.success(maintenanceTodoResponseList, ApiConstants.RESULT_SUCCESS, "获取待办数据成功");
    }

    /**
     * @param
     * @return
     * @description 获取大修待办
     * @date 2020/2/14 12:22 下午
     */
    public RestResponse getCapitalRepairTodo(TodoRequest todoRequest) {
        List<CapitalRepairResponse> capitalRepairResponseList = todoDataMapper.getCapitalRepairTodoData(todoRequest);
        return RestResponse.success(capitalRepairResponseList, ApiConstants.RESULT_SUCCESS, "获取待办数据成功");
    }

    /**
     * @param
     * @return
     * @description 获取年检待办
     * @date 2020/2/14 12:24 下午
     */
    public RestResponse getAnnualInspectionTodo(TodoRequest todoRequest) {
        List<AnnualInspectionResponse> annualInspectionResponseList = todoDataMapper
                .getAnnualInspectionTodoData(todoRequest);
        return RestResponse.success(annualInspectionResponseList, ApiConstants.RESULT_SUCCESS, "获取待办数据成功");
    }
}
